package com.vendor.platform.api.chips;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.api.chips.Chip;
import com.vendor.platform.api.chips.Tool;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import org.xml.sax.SAXException;

public class Chips {
  private static final String ID = "id";
  
  private static final String NAME = "name";
  
  private static final String PRODUCTION_LINE = "productionLine";
  
  private static final String PARAM = "param";
  
  private ArrayList<Chip> chips = new ArrayList<>();
  
  public ArrayList<Chip> getChips() {
    return this.chips;
  }
  
  public void setChips(ArrayList<Chip> chips) {
    this.chips = chips;
  }
  
  public static ArrayList<Chip> getChipList(File file) {
    ArrayList<Chip> chipList = new ArrayList<>();
    if (file == null || !file.exists())
      return chipList; 
    SAXReader reader = new SAXReader();
    try {
      reader.setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
    } catch (SAXException e) {
      return chipList;
    } 
    try {
      Document document = reader.read(file);
      if (document == null)
        return chipList; 
      Element root = document.getRootElement();
      if (root == null)
        return chipList; 
      List<Element> elementList = root.elements();
      if (elementList == null)
        return chipList; 
      for (Element element : elementList) {
        Chip chip = new Chip();
        if (!parseChipInfo(element, chip))
          continue; 
        if (!parseToolInfo(element, chip))
          continue; 
        chipList.add(chip);
      } 
    } catch (DocumentException e) {
      return chipList;
    } 
    return chipList;
  }
  
  private static boolean parseChipInfo(Element element, Chip chip) {
    if (element == null)
      return false; 
    String id = element.attributeValue("id");
    String name = element.attributeValue("name");
    String productionLine = element.attributeValue("productionLine");
    if (id == null || name == null || productionLine == null)
      return false; 
    chip.setId(id);
    chip.setName(name);
    chip.setProductionLine(productionLine);
    return true;
  }
  
  private static boolean parseToolInfo(Element element, Chip chip) {
    ArrayList<Tool> toolList = new ArrayList<>();
    List<Element> elementToolList = element.elements();
    if (elementToolList == null)
      return false; 
    for (Element elementTool : elementToolList) {
      String id = elementTool.attributeValue("id");
      String param = elementTool.attributeValue("param");
      if (id == null || param == null)
        return false; 
      Tool tool = new Tool();
      tool.setId(id);
      tool.setParam(param);
      toolList.add(tool);
    } 
    chip.setToolList(toolList);
    return true;
  }
  
  public ArrayList<String> getSuitableToolIDs(String chipName) {
    ArrayList<String> list = new ArrayList<>();
    if (this.chips.size() > 0)
      for (int i = 0; i < this.chips.size(); i++) {
        Chip chip = this.chips.get(i);
        if (chip.getName().equals(chipName)) {
          ArrayList<Tool> tools = chip.getToolList();
          if (tools.size() > 0)
            for (int j = 0; j < tools.size(); j++) {
              Tool tool = tools.get(j);
              list.add(tool.getId());
            }  
          break;
        } 
      }  
    return list;
  }
}
